# Contributing

## Issues

Issues are very valuable to this project.

  - Ideas are a valuable source of contributions you can make
  - Problems show where this project is lacking
  - With a question you show where contributors can improve the user
    experience

Thank you for creating them.

## Pull Requests

Submitting pull requests is a great way to get your ideas into this repository.

When merging in a pull request we look at the following things:

### Does it state intent

You should be clear which problem you're trying to solve with your
contribution.

For example:

> Add link to code of conduct in README.md

Doesn't tell me anything about why you're doing that

> Add link to code of conduct in README.md because users don't always
> look in the CONTRIBUTING.md

Tells me the problem that you have found, and the pull request shows me
the action you have taken to solve it.

### Is it of good quality

  - There are no spelling mistakes
  - It reads well
  - It is descriptive and to the point

### Does it move this repository closer to my vision for the repository

The aim of this repository is:

  - To provide a Xiangqi, Chinese Chess, reinforcement learning environment 
    for projects, research and experiments
  - To allow users to learn reinforcement learning in general
  - To allow users to grow interest in reinforcement learning
  - To support OpenAI Gym as a reinforcement learning framework
